﻿/*
 * Author: Guadmaz <rockeurp@gmail.com>
 * Do not redistribute this without my authorization.
 */
using System;
using System.Windows.Forms;
using GTA;
using GTA.Math;
using GTA.Native;
namespace SearchLight
{
    public class SearchLight : Script
    {
        public SearchLight()
        {
            Tick += OnTick;
            KeyDown += OnKeyDown;
            var settings = ScriptSettings.Load("scripts\\SearchLight.ini");
            if (settings != null)
            {
                _enableKey = settings.GetValue<Keys>("KEY_SETTINGS", "EnableSearchlight", Keys.NumPad0);
                _vehicleKey = settings.GetValue<Keys>("KEY_SETTINGS", "SearchVehicle", Keys.NumPad1);
                _pedKey = settings.GetValue<Keys>("KEY_SETTINGS", "SearchPerson", Keys.NumPad3);
                _debugKey = settings.GetValue<Keys>("KEY_SETTINGS", "DrawLine", Keys.Decimal);
            }
            else
            {
                _enableKey = Keys.NumPad0;
                _vehicleKey = Keys.NumPad1;
                _pedKey = Keys.NumPad3;
                _debugKey = Keys.Decimal;
            }
        }

        private Entity _targetEntity;
        private bool _debugActive;
        private bool _lightActive;

        private Keys _enableKey;
        private Keys _vehicleKey;
        private Keys _pedKey;
        private Keys _debugKey;

        void OnTick(object sender, EventArgs e)
        {
            Ped player = Game.Player.Character;
            if (_targetEntity != null && player.IsInVehicle() && _lightActive)
            {
                if (player.CurrentVehicle.Model == VehicleHash.Polmav && (_targetEntity.Position - player.Position).Length() < 150f)
                {
                    Vector3 dest = _targetEntity.Position - player.Position - player.ForwardVector*3f;
                    Vector3 origin = player.CurrentVehicle.Position + player.ForwardVector*3f - new Vector3(0, 0, 1f);
                    dest.Normalize();
                    Function.Call(Hash._0x5BCA583A583194DB, origin.X, origin.Y, origin.Z, dest.X, dest.Y, dest.Z, 255, 255, 255, (_targetEntity.Position - player.Position).Length() + 20, 10f, 1f, 5f, 10f, 0);
                    if(_debugActive)
                        Function.Call(Hash.DRAW_LINE, origin.X, origin.Y, origin.Z, _targetEntity.Position.X, _targetEntity.Position.Y, _targetEntity.Position.Z, 255, 255, 255, 255);
                }
            }
        }
        private void OnKeyDown(object sender, KeyEventArgs e)
        {
            Ped player = Game.Player.Character;
            if (e.KeyCode == _enableKey)
            {
                _lightActive = !_lightActive;
                if (_lightActive && _targetEntity == null)
                {
                    _targetEntity = World.GetClosestVehicle(player.Position, 150f);
                }
            }
            else if (e.KeyCode == _vehicleKey)
                _targetEntity = World.GetClosestVehicle(player.Position, 150f);
            else if (e.KeyCode == _pedKey)
                _targetEntity = World.GetClosestPed(player.Position, 150f);
            else if (e.KeyCode == _debugKey)
                _debugActive = !_debugActive;
        }
    }
}
